var dir_9df590563da805a074404567c6e27abf =
[
    [ "kernels", "dir_19b91ce24010a277ae42e0f12bdd020d.html", "dir_19b91ce24010a277ae42e0f12bdd020d" ],
    [ "amg_operations.hpp", "opencl_2amg__operations_8hpp.html", "opencl_2amg__operations_8hpp" ],
    [ "bisect_kernel_calls.hpp", "opencl_2bisect__kernel__calls_8hpp.html", "opencl_2bisect__kernel__calls_8hpp" ],
    [ "common.hpp", "linalg_2opencl_2common_8hpp.html", "linalg_2opencl_2common_8hpp" ],
    [ "direct_solve.hpp", "opencl_2direct__solve_8hpp.html", "opencl_2direct__solve_8hpp" ],
    [ "fft_operations.hpp", "opencl_2fft__operations_8hpp.html", "opencl_2fft__operations_8hpp" ],
    [ "ilu_operations.hpp", "opencl_2ilu__operations_8hpp.html", "opencl_2ilu__operations_8hpp" ],
    [ "iterative_operations.hpp", "opencl_2iterative__operations_8hpp.html", "opencl_2iterative__operations_8hpp" ],
    [ "matrix_operations.hpp", "opencl_2matrix__operations_8hpp.html", "opencl_2matrix__operations_8hpp" ],
    [ "misc_operations.hpp", "opencl_2misc__operations_8hpp.html", "opencl_2misc__operations_8hpp" ],
    [ "nmf_operations.hpp", "opencl_2nmf__operations_8hpp.html", "opencl_2nmf__operations_8hpp" ],
    [ "scalar_operations.hpp", "opencl_2scalar__operations_8hpp.html", "opencl_2scalar__operations_8hpp" ],
    [ "sparse_matrix_operations.hpp", "opencl_2sparse__matrix__operations_8hpp.html", "opencl_2sparse__matrix__operations_8hpp" ],
    [ "vandermonde_matrix_operations.hpp", "opencl_2vandermonde__matrix__operations_8hpp.html", "opencl_2vandermonde__matrix__operations_8hpp" ],
    [ "vector_operations.hpp", "opencl_2vector__operations_8hpp.html", "opencl_2vector__operations_8hpp" ]
];